==> istio-model-v1alpha3-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionAbortGrpcStatusFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionAbortGrpcStatusFluentImpl<A extends HTTPFaultInjectionAbortGrpcStatusFluent<A>> extends BaseFluent<A> implements HTTPFaultInjectionAbortGrpcStatusFluent<A>{
  public HTTPFaultInjectionAbortGrpcStatusFluentImpl() {
  }
  public HTTPFaultInjectionAbortGrpcStatusFluentImpl(HTTPFaultInjectionAbortGrpcStatus instance) {
    this.withGrpcStatus(instance.getGrpcStatus()); 
  }
  private String grpcStatus;
  public String getGrpcStatus() {
    return this.grpcStatus;
  }
  public A withGrpcStatus(String grpcStatus) {
    this.grpcStatus=grpcStatus; return (A) this;
  }
  public Boolean hasGrpcStatus() {
    return this.grpcStatus != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPFaultInjectionAbortGrpcStatusFluentImpl that = (HTTPFaultInjectionAbortGrpcStatusFluentImpl) o;
    if (grpcStatus != null ? !grpcStatus.equals(that.grpcStatus) :that.grpcStatus != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(grpcStatus,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (grpcStatus != null) { sb.append("grpcStatus:"); sb.append(grpcStatus); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionAbortGrpcStatusFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionAbortGrpcStatusFluentImpl<A extends HTTPFaultInjectionAbortGrpcStatusFluent<A>> extends BaseFluent<A> implements HTTPFaultInjectionAbortGrpcStatusFluent<A>{
  public HTTPFaultInjectionAbortGrpcStatusFluentImpl() {
  }
  public HTTPFaultInjectionAbortGrpcStatusFluentImpl(HTTPFaultInjectionAbortGrpcStatus instance) {
    if (instance != null) {
      this.withGrpcStatus(instance.getGrpcStatus());
    }
  }
  private String grpcStatus;
  public String getGrpcStatus() {
    return this.grpcStatus;
  }
  public A withGrpcStatus(String grpcStatus) {
    this.grpcStatus=grpcStatus; return (A) this;
  }
  public Boolean hasGrpcStatus() {
    return this.grpcStatus != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionAbortGrpcStatusFluentImpl that = (HTTPFaultInjectionAbortGrpcStatusFluentImpl) o;
    if (!java.util.Objects.equals(grpcStatus, that.grpcStatus)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(grpcStatus,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (grpcStatus != null) { sb.append("grpcStatus:"); sb.append(grpcStatus); }
    sb.append("}");
    return sb.toString();
  }
  
}
